@@ -4,6 +4,8 @@ from .svc import *
 from .dmo import *
 from .dto import *
 
+from .recipes import *
+from .recipes.filter_entity_list import filter_entity_list
 
 import logging
 
