@@ -1,4 +1,4 @@
 from .sliding_window_extract import SlidingWindowExtract
-from .sliding_window_validate import SlidingWindowValidate
+from .sliding_window_match import SlidingWindowMatch
 from .sliding_window_blacklist import SlidingWindowBlacklist
 from .candidate_fuzzy_match import CandidateFuzzyMatch
