@@ -45,7 +45,7 @@ class FindFuzzyMatches(BaseObject):
         if self.isEnabledForInfo:
             self.logger.info('\n'.join([
                 "Sliding Window Completed",
-                f"\tTotal Results: {len(d_fuzzy)}",
-                f"\tTotal Time: {str(sw)}"]))
+                f"\tTotal Time: {str(sw)}",
+                f"\tResults: {d_fuzzy}"]))
 
         return d_fuzzy
